#ifndef NVIM_SPELL_H
#define NVIM_SPELL_H

#include <stdbool.h>

#include "nvim/spell_defs.h"
#include "nvim/ex_cmds_defs.h"
#include "nvim/globals.h"

#ifdef INCLUDE_GENERATED_DECLARATIONS
# include "spell.h.generated.h"
#endif
#endif  // NVIM_SPELL_H
